summaryrefslogtreecommitdiff
path: root/src/common
diff options
context:
space:
mode:
authorNick Mathewson <nickm@torproject.org>2014-08-29 11:33:05 -0400
committerNick Mathewson <nickm@torproject.org>2014-08-29 11:33:05 -0400
commit4144b4552b00c25eba9be7a959aa75c1efbe4a18 (patch)
treea8d4f9955c3716dc10d8835835d2a3f4dad3fac4 /src/common
parentb45f0f8fb9b11effcd48159c078f09a3fbc04b11 (diff)
downloadtor-4144b4552b00c25eba9be7a959aa75c1efbe4a18.tar.gz
tor-4144b4552b00c25eba9be7a959aa75c1efbe4a18.zip
Always event_del() connection events before freeing them
Previously, we had done this only in the connection_free() case, but when we called connection_free_() directly from connections_free_all(), we didn't free the connections.
Diffstat (limited to 'src/common')
-rw-r--r--src/common/compat_libevent.c14
-rw-r--r--src/common/compat_libevent.h5
2 files changed, 15 insertions, 4 deletions
diff --git a/src/common/compat_libevent.h b/src/common/compat_libevent.h
index 2472e2c49e..ab7066beb2 100644
--- a/src/common/compat_libevent.h
+++ b/src/common/compat_libevent.h
@@ -28,11 +28,9 @@ void suppress_libevent_log_msg(const char *msg);
#define tor_event_new event_new
#define tor_evtimer_new evtimer_new
#define tor_evsignal_new evsignal_new
-#define tor_event_free event_free
#define tor_evdns_add_server_port(sock, tcp, cb, data) \
evdns_add_server_port_with_base(tor_libevent_get_base(), \
(sock),(tcp),(cb),(data));
-
#else
struct event *tor_event_new(struct event_base * base, evutil_socket_t sock,
short what, void (*cb)(evutil_socket_t, short, void *), void *arg);
@@ -40,10 +38,11 @@ struct event *tor_evtimer_new(struct event_base * base,
void (*cb)(evutil_socket_t, short, void *), void *arg);
struct event *tor_evsignal_new(struct event_base * base, int sig,
void (*cb)(evutil_socket_t, short, void *), void *arg);
-void tor_event_free(struct event *ev);
#define tor_evdns_add_server_port evdns_add_server_port
#endif
+void tor_event_free(struct event *ev);
+
typedef struct periodic_timer_t periodic_timer_t;
periodic_timer_t *periodic_timer_new(struct event_base *base,
diff --git a/src/common/compat_libevent.c b/src/common/compat_libevent.c
index 200a7c65fb..2a7386df4a 100644
--- a/src/common/compat_libevent.c
+++ b/src/common/compat_libevent.c
@@ -144,13 +144,25 @@ tor_evsignal_new(struct event_base * base, int sig,
{
return tor_event_new(base, sig, EV_SIGNAL|EV_PERSIST, cb, arg);
}
/** Work-alike replacement for event_free() on pre-Libevent-2.0 systems. */
void
tor_event_free(struct event *ev)
{
+ if (ev == NULL)
+ return;
event_del(ev);
tor_free(ev);
}
+#else
+/* Wrapper for event_free() that tolerates tor_event_free(NULL) */
+void
+tor_event_free(struct event *ev)
+{
+ if (ev == NULL)
+ return;
+ event_free(ev);
+}
#endif
/** Global event base for use by the main thread. */
@@ -144,13 +144,25 @@ tor_evsignal_new(struct event_base * base, int sig,
return tor_event_new(base, sig, EV_SIGNAL|EV_PERSIST, cb, arg);
}
-/** Work-alike replacement for event_free() on pre-Libevent-2.0 systems. */
+/** Work-alike replacement for event_free() on pre-Libevent-2.0 systems,
+ * except tolerate tor_event_free(NULL). */
void
tor_event_free(struct event *ev)